==> cordova-osx-6.0.0.tgz: package/bin/templates/scripts/cordova/lib/clean.js <==
/**
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 *  KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */

var Q = require('q');
var path = require('path');
var shell = require('shelljs');
var spawn = require('./spawn');

var projectPath = path.join(__dirname, '..', '..');

module.exports.run = function () {
    var projectName = shell.ls(projectPath).filter(function (name) {
        return path.extname(name) === '.xcodeproj';
    })[0];

    if (!projectName) {
        return Q.reject('No Xcode project found in ' + projectPath);
    }

    return spawn('xcodebuild', ['-project', projectName, '-configuration', 'Debug', '-alltargets', 'clean'], projectPath)
        .then(function () {
            return spawn('xcodebuild', ['-project', projectName, '-configuration', 'Release', '-alltargets', 'clean'], projectPath);
        }).then(function () {
            return shell.rm('-rf', path.join(projectPath, 'build'));
        });
};

==> cordova-osx-7.0.0.tgz: package/bin/templates/scripts/cordova/lib/clean.js <==
/**
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 *  KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */

const path = require('path');
const shell = require('shelljs');
const spawn = require('./spawn');

const projectPath = path.join(__dirname, '..', '..');

module.exports.run = function () {
    const projectName = shell.ls(projectPath).filter(function (name) {
        return path.extname(name) === '.xcodeproj';
    })[0];

    if (!projectName) {
        return Promise.reject('No Xcode project found in ' + projectPath);
    }

    return spawn('xcodebuild', ['-project', projectName, '-configuration', 'Debug', '-alltargets', 'clean'], projectPath)
        .then(function () {
            return spawn('xcodebuild', ['-project', projectName, '-configuration', 'Release', '-alltargets', 'clean'], projectPath);
        }).then(function () {
            return shell.rm('-rf', path.join(projectPath, 'build'));
        });
};
